==> qcad-3.15.5.3.tgz: lib/qcad/scripts/Draw/Ellipse/EllipseOffsetThrough/ts/EllipseOffsetThrough_pl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pl_PL">
<context>
    <name>CircleConcentricThrough</name>
    <message>
        <source>Number:</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pl.ts--
Wprowadź liczbę:
Liczba:</translatorcomment>
        <translation type="obsolete">Liczba:</translation>
    </message>
    <message>
        <source>Concentric (&amp;through Point)</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">Koncentryczny (poprzez Point)</translation>
    </message>
    <message>
        <source>Draw concentric circle through point</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">Remis koncentryczny okrąg przez punkt</translation>
    </message>
</context>
<context>
    <name>EllipseConcentricThrough</name>
    <message>
        <source>Number:</source>
        <translation type="obsolete">Liczba:</translation>
    </message>
</context>
<context>
    <name>EllipseOffsetThrough</name>
    <message>
        <location filename="../EllipseOffsetThrough.ui" line="+17"/>
        <source>Number:</source>
        <translation type="unfinished">Liczba:</translation>
    </message>
    <message>
        <location filename="../EllipseOffsetThroughInit.js" line="+2"/>
        <source>Parallel Curve (&amp;through Point)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Draw parallel curve to ellipse through point</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>

==> qcad-3.21.2.3.tgz: lib/qcad/scripts/Draw/Ellipse/EllipseOffsetThrough/ts/EllipseOffsetThrough_pl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pl">
<context>
    <name>CircleConcentricThrough</name>
    <message>
        <source>Number:</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pl.ts--
Wprowadź liczbę:
Liczba:</translatorcomment>
        <translation type="obsolete">Liczba:</translation>
    </message>
    <message>
        <source>Concentric (&amp;through Point)</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">Koncentryczny (poprzez Point)</translation>
    </message>
    <message>
        <source>Draw concentric circle through point</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">Remis koncentryczny okrąg przez punkt</translation>
    </message>
</context>
<context>
    <name>EllipseConcentricThrough</name>
    <message>
        <source>Number:</source>
        <translation type="obsolete">Liczba:</translation>
    </message>
</context>
<context>
    <name>EllipseOffsetThrough</name>
    <message>
        <location filename="../EllipseOffsetThrough.ui" line="+17"/>
        <source>Number:</source>
        <translation>Ilość:</translation>
    </message>
    <message>
        <location filename="../EllipseOffsetThroughInit.js" line="+2"/>
        <source>Parallel Curve (&amp;through Point)</source>
        <translation>Równoległa krzywa (pr&amp;zez punkt)</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Draw parallel curve to ellipse through point</source>
        <translation>Rysuje krzywą równoległą do elipsy przez punkt</translation>
    </message>
</context>
</TS>
